@@ -27,12 +27,13 @@ from typing_extensions import Final, TypeAlias
 from textual._cells import cell_len
 from textual._context import active_app
 from textual._loop import loop_last
+from textual.cache import FIFOCache
 from textual.color import Color
 from textual.css.types import TextAlign, TextOverflow
 from textual.selection import Selection
 from textual.strip import Strip
 from textual.style import Style
-from textual.visual import RulesMap, Visual
+from textual.visual import RenderOptions, RulesMap, Visual
 
 __all__ = ["ContentType", "Content", "Span"]
 
@@ -138,7 +139,14 @@ class Content(Visual):
         self._spans: list[Span] = [] if spans is None else spans
         self._cell_length = cell_length
         self._optimal_width_cache: int | None = None
+        self._minimal_width_cache: int | None = None
         self._height_cache: tuple[tuple[int, str, bool] | None, int] = (None, 0)
+        self._divide_cache: (
+            FIFOCache[Sequence[int], list[tuple[Span, int, int]]] | None
+        ) = None
+        self._split_cache: FIFOCache[tuple[str, bool, bool], list[Content]] | None = (
+            None
+        )
 
     def __str__(self) -> str:
         return self._text
@@ -327,7 +335,9 @@ class Content(Visual):
         if not text:
             return Content("")
         span_length = cell_len(text) if cell_length is None else cell_length
-        new_content = cls(text, [Span(0, span_length, style)], span_length)
+        new_content = cls(
+            text, [Span(0, span_length, style)] if style else None, span_length
+        )
         return new_content
 
     @classmethod
@@ -441,6 +451,21 @@ class Content(Visual):
             width = self._optimal_width_cache
         return width + rules.get("line_pad", 0) * 2
 
+    def get_minimal_width(self, rules: RulesMap) -> int:
+        """Minimal width is the largest single word."""
+        if not self.plain.strip():
+            return 0
+        if self._minimal_width_cache is None:
+            self._minimal_width_cache = width = max(
+                cell_len(word)
+                for line in self.plain.splitlines()
+                for word in line.split()
+                if word.strip()
+            )
+        else:
+            width = self._minimal_width_cache
+        return width + rules.get("line_pad", 0) * 2
+
     def get_height(self, rules: RulesMap, width: int) -> int:
         """Get the height of the Visual if rendered at the given width.
 
@@ -477,6 +502,7 @@ class Content(Visual):
         selection: Selection | None = None,
         selection_style: Style | None = None,
         post_style: Style | None = None,
+        get_style: Callable[[str | Style], Style] = Style.parse,
     ) -> list[_FormattedLine]:
         """Wraps the text and applies formatting.
 
@@ -518,15 +544,17 @@ class Content(Visual):
                 if overflow == "fold":
                     cuts = list(range(0, line.cell_length, width))[1:]
                     new_lines = [
-                        _FormattedLine(line, width, y=y, align=align)
+                        _FormattedLine(get_style, line, width, y=y, align=align)
                         for line in line.divide(cuts)
                     ]
                 else:
                     line = line.truncate(width, ellipsis=overflow == "ellipsis")
-                    content_line = _FormattedLine(line, width, y=y, align=align)
+                    content_line = _FormattedLine(
+                        get_style, line, width, y=y, align=align
+                    )
                     new_lines = [content_line]
             else:
-                content_line = _FormattedLine(line, width, y=y, align=align)
+                content_line = _FormattedLine(get_style, line, width, y=y, align=align)
                 offsets = divide_line(
                     line.plain, width - line_pad * 2, fold=overflow == "fold"
                 )
@@ -543,6 +571,7 @@ class Content(Visual):
 
                 new_lines = [
                     _FormattedLine(
+                        get_style,
                         content.rstrip_end(width).pad(line_pad, line_pad),
                         width,
                         offset,
@@ -558,25 +587,15 @@ class Content(Visual):
         return output_lines
 
     def render_strips(
-        self,
-        rules: RulesMap,
-        width: int,
-        height: int | None,
-        style: Style,
-        selection: Selection | None = None,
-        selection_style: Style | None = None,
-        post_style: Style | None = None,
+        self, width: int, height: int | None, style: Style, options: RenderOptions
     ) -> list[Strip]:
-        """Render the visual into an iterable of strips. Part of the Visual protocol.
+        """Render the Visual into an iterable of strips. Part of the Visual protocol.
 
         Args:
-            rules: A mapping of style rules, such as the Widgets `styles` object.
             width: Width of desired render.
             height: Height of desired render or `None` for any height.
             style: The base style to render on top of.
-            selection: Selection information, if applicable, otherwise `None`.
-            selection_style: Selection style if `selection` is not `None`.
-            post_style: Style | None = None,
+            options: Additional render options.
 
         Returns:
             An list of Strips.
@@ -585,7 +604,7 @@ class Content(Visual):
         if not width:
             return []
 
-        get_rule = rules.get
+        get_rule = options.rules.get
         lines = self._wrap_and_format(
             width,
             align=get_rule("text_align", "left"),
@@ -593,9 +612,10 @@ class Content(Visual):
             no_wrap=get_rule("text_wrap", "wrap") == "nowrap",
             line_pad=get_rule("line_pad", 0),
             tab_size=8,
-            selection=selection,
-            selection_style=selection_style,
-            post_style=post_style,
+            selection=options.selection,
+            selection_style=options.selection_style,
+            post_style=options.post_style,
+            get_style=options.get_style,
         )
 
         if height is not None:
@@ -799,6 +819,7 @@ class Content(Visual):
             extend_spans(
                 _Span(offset + start, offset + end, style)
                 for start, end, style in content._spans
+                if style
             )
             offset += len(content._text)
             if total_cell_length is not None:
@@ -1099,7 +1120,7 @@ class Content(Visual):
         get_style: Callable[[str | Style], Style]
         if parse_style is None:
 
-            def get_style(style: str | Style) -> Style:
+            def _get_style(style: str | Style) -> Style:
                 """The default get_style method."""
                 if isinstance(style, Style):
                     return style
@@ -1109,6 +1130,8 @@ class Content(Visual):
                     visual_style = Style.null()
                 return visual_style
 
+            get_style = _get_style
+
         else:
             get_style = parse_style
 
@@ -1178,38 +1201,29 @@ class Content(Visual):
         ]
         return segments
 
-    def divide(self, offsets: Sequence[int]) -> list[Content]:
-        """Divide the content at the given offsets.
-
-        This will cut the content in to pieces, and return those pieces. Note that the number of pieces
-        return will be one greater than the number of cuts.
+    def _divide_spans(self, offsets: tuple[int, ...]) -> list[tuple[Span, int, int]]:
+        """Divide content from a list of offset to cut.
 
         Args:
-            offsets: Sequence of offsets (in characters) of where to apply the cuts.
+            offsets: A tuple of indices in to the text.
 
         Returns:
-            List of Content instances which combined would be equal to the whole.
+            A list of tuples containing Spans and their line offsets.
         """
-        if not offsets:
-            return [self]
+        if self._divide_cache is None:
+            self._divide_cache = FIFOCache(4)
+        if (cached_result := self._divide_cache.get(offsets)) is not None:
+            return cached_result
 
-        offsets = sorted(offsets)
-
-        text = self.plain
-        text_length = len(text)
-        divide_offsets = [0, *offsets, text_length]
-        line_ranges = list(zip(divide_offsets, divide_offsets[1:]))
-
-        new_lines = [Content(text[start:end]) for start, end in line_ranges]
-
-        if not self._spans:
-            return new_lines
-
-        _line_appends = [line._spans.append for line in new_lines]
+        line_ranges = list(zip(offsets, offsets[1:]))
+        text_length = len(self.plain)
         line_count = len(line_ranges)
-        _Span = Span
-
-        for span_start, span_end, style in self._spans:
+        span_ranges: list[tuple[Span, int, int]] = []
+        for span in self._spans:
+            span_start, span_end, _style = span
+            if span_start >= text_length:
+                continue
+            span_end = min(text_length, span_end)
             lower_bound = 0
             upper_bound = line_count
             start_line_no = (lower_bound + upper_bound) // 2
@@ -1240,7 +1254,44 @@ class Content(Visual):
                         break
                     end_line_no = (lower_bound + upper_bound) // 2
 
-            for line_no in range(start_line_no, end_line_no + 1):
+            span_ranges.append((span, start_line_no, end_line_no + 1))
+        self._divide_cache[offsets] = span_ranges
+        return span_ranges
+
+    def divide(self, offsets: Sequence[int]) -> list[Content]:
+        """Divide the content at the given offsets.
+
+        This will cut the content in to pieces, and return those pieces. Note that the number of pieces
+        return will be one greater than the number of cuts.
+
+        Args:
+            offsets: Sequence of offsets (in characters) of where to apply the cuts.
+
+        Returns:
+            List of Content instances which combined would be equal to the whole.
+        """
+        if not offsets:
+            return [self]
+
+        offsets = sorted(offsets)
+        text = self.plain
+        divide_offsets = tuple([0, *offsets, len(text)])
+        line_ranges = list(zip(divide_offsets, divide_offsets[1:]))
+        line_text = [text[start:end] for start, end in line_ranges]
+        new_lines = [Content(line, None) for line in line_text]
+
+        if not self._spans:
+            return new_lines
+
+        _line_appends = [line._spans.append for line in new_lines]
+        _Span = Span
+
+        for (
+            (span_start, span_end, style),
+            start_line,
+            end_line,
+        ) in self._divide_spans(divide_offsets):
+            for line_no in range(start_line, end_line):
                 line_start, line_end = line_ranges[line_no]
                 new_start = max(0, span_start - line_start)
                 new_end = min(span_end - line_start, line_end - line_start)
@@ -1267,11 +1318,16 @@ class Content(Visual):
             List[Content]: A list of Content, one per line of the original.
         """
         assert separator, "separator must not be empty"
-
         text = self.plain
         if separator not in text:
             return [self]
 
+        cache_key = (separator, include_separator, allow_blank)
+        if self._split_cache is None:
+            self._split_cache = FIFOCache(4)
+        if (cached_result := self._split_cache.get(cache_key)) is not None:
+            return cached_result.copy()
+
         if include_separator:
             lines = self.divide(
                 [match.end() for match in re.finditer(re.escape(separator), text)],
@@ -1291,6 +1347,7 @@ class Content(Visual):
         if not allow_blank and text.endswith(separator):
             lines.pop()
 
+        self._split_cache[cache_key] = lines
         return lines
 
     def rstrip(self, chars: str | None = None) -> Content:
@@ -1416,6 +1473,7 @@ class _FormattedLine:
 
     def __init__(
         self,
+        get_style: Callable[[str | Style], Style],
         content: Content,
         width: int,
         x: int = 0,
@@ -1424,6 +1482,7 @@ class _FormattedLine:
         line_end: bool = False,
         link_style: Style | None = None,
     ) -> None:
+        self.get_style = get_style
         self.content = content
         self.width = width
         self.x = x
@@ -1444,6 +1503,7 @@ class _FormattedLine:
         content = self.content
         x = self.x
         y = self.y
+        get_style = self.get_style
 
         if align in ("start", "left") or (align == "justify" and self.line_end):
             pass
@@ -1472,7 +1532,9 @@ class _FormattedLine:
             add_segment = segments.append
             x = self.x
             for index, word in enumerate(words):
-                for text, text_style in word.render(style, end=""):
+                for text, text_style in word.render(
+                    style, end="", parse_style=get_style
+                ):
                     add_segment(
                         _Segment(
                             text, (style + text_style).rich_style_with_offset(x, y)
@@ -1490,7 +1552,7 @@ class _FormattedLine:
             else []
         )
         add_segment = segments.append
-        for text, text_style in content.render(style, end=""):
+        for text, text_style in content.render(style, end="", parse_style=get_style):
             add_segment(
                 _Segment(text, (style + text_style).rich_style_with_offset(x, y))
             )
